Crate vosk_sys

Crate vosk_sys 

Structs

VoskBatchModel
VoskBatchRecognizer
VoskModel
VoskRecognizer
VoskSpkModel

Functions

vosk_batch_model_free⚠
Releases batch model object
vosk_batch_model_new⚠
Creates the batch recognizer object
vosk_batch_model_wait⚠
Wait for the processing
vosk_batch_recognizer_accept_waveform⚠
Accept batch voice data
vosk_batch_recognizer_finish_stream⚠
Closes the stream
vosk_batch_recognizer_free⚠
Releases batch recognizer object
vosk_batch_recognizer_front_result⚠
Return results
vosk_batch_recognizer_get_pending_chunks⚠
Get amount of pending chunks for more intelligent waiting
vosk_batch_recognizer_new⚠
Creates batch recognizer object @returns recognizer object or NULL if problem occured
vosk_batch_recognizer_pop⚠
Release and free first retrieved result
vosk_batch_recognizer_set_nlsml⚠
Set NLSML output @param nlsml - boolean value
vosk_gpu_init⚠
Init, automatically select a CUDA device and allow multithreading. Must be called once from the main thread. Has no effect if HAVE_CUDA flag is not set.
vosk_gpu_thread_init⚠
Init CUDA device in a multi-threaded environment. Must be called for each thread. Has no effect if HAVE_CUDA flag is not set.
vosk_model_find_word⚠
Check if a word can be recognized by the model @param word: the word @returns the word symbol if @param word exists inside the model or -1 otherwise. Reminding that word symbol 0 is for <epsilon>
vosk_model_free⚠
Releases the model memory
vosk_model_new⚠
Loads model data from the file and returns the model object
vosk_recognizer_accept_waveform⚠
Accept voice data
vosk_recognizer_accept_waveform_f⚠
Same as above but the version with the float data for language bindings where you have audio as array of floats
vosk_recognizer_accept_waveform_s⚠
Same as above but the version with the short data for language bindings where you have audio as array of shorts
vosk_recognizer_final_result⚠
Returns speech recognition result. Same as result, but doesn’t wait for silence You usually call it in the end of the stream to get final bits of audio. It flushes the feature pipeline, so all remaining audio chunks got processed.
vosk_recognizer_free⚠
Releases recognizer object
vosk_recognizer_new⚠
Creates the recognizer object
vosk_recognizer_new_grm⚠
Creates the recognizer object with the phrase list
vosk_recognizer_new_spk⚠
Creates the recognizer object with speaker recognition
vosk_recognizer_partial_result⚠
Returns partial speech recognition
vosk_recognizer_reset⚠
Resets the recognizer
vosk_recognizer_result⚠
Returns speech recognition result
vosk_recognizer_set_max_alternatives⚠
Configures recognizer to output n-best results
vosk_recognizer_set_nlsml⚠
Set NLSML output @param nlsml - boolean value
vosk_recognizer_set_partial_words⚠
Like above return words and confidences in partial results
vosk_recognizer_set_spk_model⚠
Adds speaker model to already initialized recognizer
vosk_recognizer_set_words⚠
Enables words with times in the output
vosk_set_log_level⚠
Set log level for Kaldi messages
vosk_spk_model_free⚠
Releases the model memory
vosk_spk_model_new⚠
Loads speaker model data from the file and returns the model object